# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a dialog to enter the data for the dumpdata command.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_DjangoDumpdataDataDialog import Ui_DjangoDumpdataDataDialog

class DjangoDumpdataDataDialog(QDialog, Ui_DjangoDumpdataDataDialog):
    """
    Class implementing a dialog to enter the data for the dumpdata command.
    """
    def __init__(self, project, parent = None):
        """
        Constructor
        
        @param project reference to the Django project object
        @param parent parent widget (QWidget)
        """
        QDialog.__init__(self, parent)
        self.setupUi(self)
        
        self.__project = project
        if self.__project.getDjangoVersion() < (1, 0):
            self.excludeGroup.setEnabled(False)
        
        apps = self.__project.getRecentApplications()
        self.applicationsCombo.addItems(apps)
        self.excludeCombo.addItems(apps)
        self.excludeCombo.setEditText("")
        
        self.formatCombo.addItem(self.trUtf8("JSON"), QVariant("json"))
        self.formatCombo.addItem(self.trUtf8("XML"), QVariant("xml"))
        try:
            import yaml
            self.formatCombo.addItem(self.trUtf8("YAML"), QVariant("yaml"))
        except ImportError:
            pass
    
    def getData(self):
        """
        Public method to get the data entered into the dialog.
        
        @return tuple of two string lists (QStringList) and two strings giving
            the list of applications to work on, the list of applications to
            exclude, the dump format and the dump file name
        """
        applStr = self.applicationsCombo.currentText()
        if not applStr.isEmpty():
            self.__project.setMostRecentApplication(applStr)
            appls = applStr.split(" ", QString.SkipEmptyParts)
        else:
            appls = QStringList()
        
        exclStr = self.excludeCombo.currentText()
        if not exclStr.isEmpty():
            excl = exclStr.split(" ", QString.SkipEmptyParts)
        else:
            excl = QStringList()
        
        format = \
            unicode(self.formatCombo.itemData(self.formatCombo.currentIndex()).toString())
        
        return appls, excl, format
