# -*- coding: utf-8 -*-

# Copyright (c) 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Pylons configuration page.
"""

import sys

from PyQt4.QtCore import QStringList, pyqtSignature
from PyQt4.QtGui import QFileDialog

from KdeQt import KQFileDialog

from E4Gui.E4Completers import E4DirCompleter

from Preferences.ConfigurationPages.ConfigurationPageBase import ConfigurationPageBase
from Ui_PylonsPage import Ui_PylonsPage

import Utilities

class PylonsPage(ConfigurationPageBase, Ui_PylonsPage):
    """
    Class implementing the Pylons configuration page.
    """
    def __init__(self, plugin):
        """
        Constructor
        
        @param plugin reference to the plugin object
        """
        ConfigurationPageBase.__init__(self)
        self.setupUi(self)
        self.setObjectName("PylonsPage")
        
        self.__plugin = plugin
        
        consoleList = QStringList()
        if sys.platform == "win32":
            consoleList.append("cmd.exe /c")
        else:
            consoleList.append("konsole -e")
            consoleList.append("@konsole --workdir . -e") # KDE4 konsole spawns
            consoleList.append("gnome-terminal -x")
            consoleList.append("xterm -e")
        
        consoleNoCloseList = QStringList()
        if sys.platform == "win32":
            consoleNoCloseList.append("cmd.exe /k")
        else:
            consoleNoCloseList.append("konsole --noclose -e")
            consoleNoCloseList.append("@konsole --noclose --workdir . -e") # KDE4 konsole spawns
            consoleNoCloseList.append("xterm -hold -e")
        
        self.consoleCommandCombo.addItems(consoleList)
        self.consoleCommandNoCloseCombo.addItems(consoleNoCloseList)
        
        self.virtualEnvCompleter = E4DirCompleter(self.virtualEnvEdit)
        
        # set initial values
        self.consoleCommandCombo.setEditText(
            self.__plugin.getPreferences("ConsoleCommand"))
        self.consoleCommandNoCloseCombo.setEditText(
            self.__plugin.getPreferences("ConsoleCommandNoClose"))
        
        self.virtualEnvEdit.setText(
            self.__plugin.getPreferences("VirtualEnvironment"))
        
        self.portSpinBox.setValue(
            self.__plugin.getPreferences("ServerPort"))
        
        self.plainPythonCheckBox.setChecked(
            self.__plugin.getPreferences("UsePlainPython"))
        
        self.urlEdit.setText(
            self.__plugin.getPreferences("PylonsDocUrl"))
    
    def save(self):
        """
        Public slot to save the Pylons configuration.
        """
        self.__plugin.setPreferences("ConsoleCommand", 
            self.consoleCommandCombo.currentText())
        self.__plugin.setPreferences("ConsoleCommandNoClose", 
            self.consoleCommandNoCloseCombo.currentText())
        
        self.__plugin.setPreferences("VirtualEnvironment", 
            self.virtualEnvEdit.text())
        
        self.__plugin.setPreferences("ServerPort", 
            self.portSpinBox.value())
        
        self.__plugin.setPreferences("UsePlainPython", 
            int(self.plainPythonCheckBox.isChecked()))
        
        self.__plugin.setPreferences("PylonsDocUrl", 
            self.urlEdit.text())
    
    @pyqtSignature("")
    def on_virtualEnvButton_clicked(self):
        """
        Private slot to select the virtual environment via a directory selection dialog.
        """
        virtualEnv = KQFileDialog.getExistingDirectory(\
            self,
            self.trUtf8("Select Virtual Environment"),
            self.virtualEnvEdit.text(),
            QFileDialog.Options(QFileDialog.Option(0)))
        
        if not virtualEnv.isNull():
            self.virtualEnvEdit.setText(Utilities.toNativeSeparators(virtualEnv))
