# -*- coding: utf-8 -*-

# Copyright (c) 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a dialog for entering the create parameters.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_CreateParametersDialog import Ui_CreateParametersDialog

class CreateParametersDialog(QDialog, Ui_CreateParametersDialog):
    """
    Class implementing a dialog for entering the create parameters
    """
    def __init__(self, parent = None):
        """
        Constructor
        
        @param parent reference to the parent widget (QWidget)
        """
        QDialog.__init__(self, parent)
        self.setupUi(self)
        
        self.__okButton = self.buttonBox.button(QDialogButtonBox.Ok)
        self.__okButton.setEnabled(False)
        
        self.templateCombo.addItems(["pylons", "pylons_minimal"])
        self.templateCombo.setCurrentIndex(0)
    
    @pyqtSignature("QString")
    def on_templateCombo_textChanged(self, text):
        """
        Private slot to handle changes of the entered template.
        
        @param text text of the combo box (QString)
        """
        self.__updateUi()
    
    @pyqtSignature("QString")
    def on_nameEdit_textChanged(self, text):
        """
        Private slot to handle changes of the project name.
        
        @param text text of the combo box (QString)
        """
        self.__updateUi()
    
    def __updateUi(self):
        """
        Private slot to update the dialog.
        """
        self.__okButton.setEnabled(
            not self.templateCombo.currentText().isEmpty() and \
            not self.nameEdit.text().isEmpty()
        )
    
    def getData(self):
        """
        Public method to get the data.
        
        @return tuple giving the template (string) and the project name (string)
        """
        return (
            unicode(self.templateCombo.currentText()), 
            unicode(self.nameEdit.text())
        )
