# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Changes preview dialog.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from PreviewDialogBase import PreviewDialogBase

class ChangesPreviewDialog(PreviewDialogBase):
    """
    Class implementing the Changes preview dialog.
    """
    ChangeRole = Qt.UserRole
    
    def __init__(self, changes, parent):
        """
        Constructor
        
        @param changes reference to the Changes object (rope.base.change.ChangeSet)
        @param parent reference to the parent widget (QWidget)
        """
        PreviewDialogBase.__init__(self, parent)
        
        self.buttonBox.addButton(self.trUtf8("&Apply Changes"), 
            QDialogButtonBox.AcceptRole)
        self.buttonBox.addButton(QDialogButtonBox.Cancel)
        
        self.description.setText(changes.description)
        for change in changes.changes:
            itm = QListWidgetItem(unicode(change), self.changesList)
            try:
                changeDescription = change.get_description()
            except AttributeError:
                changeDescription = self.trUtf8("No changes available.")
            itm.setData(ChangesPreviewDialog.ChangeRole, 
                        QVariant(changeDescription))
        if self.changesList.count():
            self.changesList.item(0).setSelected(True)
    
    @pyqtSignature("QListWidgetItem*, QListWidgetItem*")
    def on_changesList_currentItemChanged(self, current, previous):
        """
        Private slot called when a change is selected.
        
        @param current reference to the new current item (QListWidgetItem)
        @param previous reference to the old current item (QListWidgetItem)
        """
        if current is None:
            return
        
        self.previewEdit.clear()
        for line in unicode(current.data(ChangesPreviewDialog.ChangeRole).toString())\
                    .splitlines(True):
            try:
                format = self.formats[line[0]]
            except (IndexError, KeyError):
                format = self.formats[' ']
            self._appendText(line, format)
