# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the autocompletion interface to rope.
"""

import os
import sys

sys.path.insert(0, os.path.dirname(__file__))

import rope.base.libutils
import rope.contrib.codeassist

from PyQt4.QtCore import *
from PyQt4.QtGui import *

class CodeAssist(QObject):
    """
    Class implementing the autocompletion interface to rope.
    """
    def __init__(self, refactoring, editor, plugin, parent = None):
        """
        Constructor
        
        @param refactoring reference to the rope refactoring object (Refactoring)
        @param editor reference to the editor object, that called this method
            QScintilla.Editor)
        @param plugin reference to the plugin object
        @param parent parent (QObject)
        """
        QObject.__init__(self, parent)
        
        self.__refactoring = refactoring
        self.__editor = editor
        self.__plugin = plugin
    
    def getCompletions(self):
        """
        Public method to calculate the possible completions.
        
        @return list of proposals (QStringList)
        """
        project = self.__refactoring.getProject()
        project.validate(project.root)
        filename = self.__editor.getFileName()
        if filename:
            resource = rope.base.libutils.path_to_resource(project, filename)
        else:
            resource = None
        line, index = self.__editor.getCursorPosition()
        offset = self.__editor.positionFromLineIndex(line, index)
        source = unicode(self.__editor.text())
        maxfixes = self.__plugin.getPreferences("MaxFixes")
        try:
            proposals = rope.contrib.codeassist.code_assist(
                project, source, offset, resource, maxfixes = maxfixes)
            proposals = rope.contrib.codeassist.sorted_proposals(proposals)
            names = [proposal.name for proposal in proposals]
            return QStringList(names)
        except Exception, err:
            return QStringList()
    
    def getCallTips(self, pos):
        """
        Public method to calculate calltips.
        
        @param pos position in the text for the calltip (integer)
        @return list of possible calltips (list of strings)
        """
        project = self.__refactoring.getProject()
        project.validate(project.root)
        filename = self.__editor.getFileName()
        if filename:
            resource = rope.base.libutils.path_to_resource(project, filename)
        else:
            resource = None
        source = unicode(self.__editor.text())
        maxfixes = self.__plugin.getPreferences("CalltipsMaxFixes")
        try:
            cts = rope.contrib.codeassist.get_calltip(
                project, source, pos, resource, maxfixes = maxfixes, remove_self = True)
            if cts is not None:
                cts = [cts]
            else:
                cts = []
        except Exception, err:
            cts = []
        return cts
