# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a dialog to show errors found by the find_errors function.
"""

from PyQt4.QtCore import *
from PyQt4.QtGui import *

from KdeQt.KQApplication import e4App

from Ui_ErrorsDialog import Ui_ErrorsDialog

class ErrorsDialog(QDialog, Ui_ErrorsDialog):
    """
    Class implementing a dialog to show errors found by the find_errors function.
    """
    def __init__(self, ui, parent = None, name = None):
        """
        Constructor
        
        @param ui reference to the UI object
        @param parent parent of this dialog (QWidget)
        @param name name of this dialog (string or QString)
        """
        QDialog.__init__(self, parent)
        if name:
            self.setObjectName(name)
        self.setupUi(self)
        
        self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
        
        self.ui = ui
        
        self.errorsList.header().setSortIndicator(0, Qt.AscendingOrder)
        
    def __resort(self):
        """
        Private method to resort the tree.
        """
        self.errorsList.sortItems(self.errorsList.sortColumn(), 
                                   self.errorsList.header().sortIndicatorOrder())
        
    def __resizeColumns(self):
        """
        Private method to resize the list columns.
        """
        self.errorsList.header().resizeSections(QHeaderView.ResizeToContents)
        self.errorsList.header().setStretchLastSection(True)
        
    def on_errorsList_itemActivated(self, itm, column):
        """
        Private slot to handle the itemActivated signal of the list.
        """
        lineno = int(str(itm.text(1)))
        fn = unicode(itm.text(0))
        e4App().getObject("ViewManager").openSourceFile(fn, lineno)
        
    def addEntry(self, resource, lineno, error):
        """
        Public slot to add an entry to the list.
        
        @param resource reference to the resource object 
            (rope.base.resources.Resource)
        @param lineno linenumber of the match (integer)
        @param error error message (string)
        """
        itm = QTreeWidgetItem(self.errorsList, QStringList() \
            << resource.real_path << " %5d" % lineno << error)
        itm.setTextAlignment(1, Qt.AlignRight)
        itm.setTextAlignment(2, Qt.AlignRight)
        self.__resort()
        self.__resizeColumns()
