# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a dialog base class to preview changes.
"""

import sys

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_PreviewDialog import Ui_PreviewDialog

class PreviewDialogBase(QDialog, Ui_PreviewDialog):
    """
    Class implementing a dialog base class to preview changes.
    """
    def __init__(self, parent = None):
        """
        Constructor
        
        @param parent reference to the parent widget (QWidget)
        """
        QDialog.__init__(self, parent)
        self.setAttribute(Qt.WA_DeleteOnClose)
        self.setupUi(self)
        
        if sys.platform == "win32":
            self.previewEdit.setFontFamily("Lucida Console")
        else:
            self.previewEdit.setFontFamily("Monospace")
        
        self.formats = {}
        self.formats[' '] = self.previewEdit.currentCharFormat()
        format = self.previewEdit.currentCharFormat()
        format.setBackground(QBrush(QColor(190, 237, 190)))
        self.formats['+'] = format
        format = self.previewEdit.currentCharFormat()
        format.setBackground(QBrush(QColor(237, 190, 190)))
        self.formats['-'] = format
        format = self.previewEdit.currentCharFormat()
        format.setBackground(QBrush(QColor(190, 190, 237)))
        self.formats['@'] = format
        format = self.previewEdit.currentCharFormat()
        format.setBackground(QBrush(QColor(124, 124, 124)))
        self.formats['?'] = format
        format = self.previewEdit.currentCharFormat()
        format.setBackground(QBrush(QColor(190, 190, 190)))
        self.formats['='] = format
    
    def _appendText(self, txt, format):
        """
        Restricted method to append text to the end of the contents pane.
        
        @param txt text to insert (QString)
        @param format text format to be used (QTextCharFormat)
        """
        tc = self.previewEdit.textCursor()
        tc.movePosition(QTextCursor.End)
        self.previewEdit.setTextCursor(tc)
        self.previewEdit.setCurrentCharFormat(format)
        self.previewEdit.insertPlainText(txt)
